@@ -30,7 +30,7 @@
 #' @param plot.theme Theme for the plot. See Details for options
 #' [default theme_dartR()].
 #' @param plot.colors.pop A color palette for population plots or a list with
-#' as many colors as there are populations in the dataset
+#' as many colors as there are populations in the dataset 
 #' [default gl.colors("dis")].
 #' @param plot.colors.ind List of two color names for the borders and fill of
 #' the plot by individual [default gl.colors(2)].
@@ -136,7 +136,9 @@
 #' To test the effect of five population sample sizes (n = 10, 5, 4, 3, 2) on 
 #' observed heterozygosity estimates, the function subsamples individuals,
 #'  without replacement. The subsampling is repeated 10 times for each sample
-#'   size n. This approach is an implementation of Schmidt et al (2021). 
+#'   size n. This approach is not an implementation of Schmidt et al (2021). 
+#'   Please refer to this paper for additional complexities in estimating
+#'   heterozygosity using SNP data.
 #'  
 #'   \strong{Error bars}
 #'  
@@ -631,8 +633,13 @@ gl.report.heterozygosity <- function(x,
     # bootstrapping
     if (nboots > 0) {
       pop_boot <- lapply(sgl, function(y) {
-        df <- as.data.frame(as.matrix(y))
         
+        df <- as.matrix(y)
+        
+        if(boot.method == "loc"){
+          df <- t(df)
+        }
+
         res_boots <- boot::boot(
           data = df,
           statistic = pop.het,
@@ -1034,11 +1041,14 @@ gl.report.heterozygosity <- function(x,
         plot.theme
     }
     
-    outliers_temp <-
+    if (plot.display) 
+      {
+      outliers_temp <-
       ggplot_build(p1)$data[[1]]$outliers[[1]]
     outliers <-
       data.frame(ID = as.character(df$ind.name[df$Ho %in% outliers_temp]),
                  Ho = outliers_temp)
+    }
     
     # OUTPUT REPORT
     if (verbose >= 3) {
